==> scathach-api-1.4.3.tar.gz: scathach-api-1.4.3/README.md <==
# scathach-api
[![pip](https://img.shields.io/pypi/v/scathach-api)](https://pypi.org/project/scathach-api/)
[![CodeFactor](https://www.codefactor.io/repository/github/sinkaroid/scathach-api.py/badge)](https://www.codefactor.io/repository/github/sinkaroid/Scathachsh)
[![chat](https://img.shields.io/discord/734526032031514786?color=purple)](https://discord.gg/ykbD7zj)  
An advanced NSFW wrapper, complete rewrite and overhaul of the original Fate/Lewd Order API.  



# Install
```
pip install scathach-api
```

### Endpoints
call them as functions  

| Function | Description |
| -------- | ----------- |
| `abigail` | Get a nsfwURL of a abigail (fate/grand order) image |
| `anastasia` | Get a nsfwURL of a anastasia (fate/grand order) image |
| `artoria` | Get a nsfwURL of a artoria (fate_all) image |
| `bb` | Get a nsfwURL of a bb (fate_all) image|
| `consort_yu`  | Get a nsfwURL of a consort_yu (fate/grand order) image |
| `davinci` | Get a nsfwURL of a davinci (fate/grand order) image |
| `ereshkigal` | Get a nsfwURL of a ereshkigal (fate/grand order) image |
| `gudako` | Get a nsfwURL of a gudako (fate/grand order) image |
| `himiko` | Get a nsfwURL of a himiko (fate/grand order) image |
| `jeanne` | Get a nsfwURL of a jeanne (fate_all) image |
| `kama` | Get a nsfwURL of a kama (fate/grand order) image |
| `kiara` | Get a nsfwURL of a kiara (fate/grand order) image |
| `mashu` | Get a nsfwURL of a mashu (fate/grand order) image |
| `mordred` | Get a nsfwURL of a mordred (fate_all) image |
| `nero` | Get a nsfwURL of a nero (fate_all) image |
| `okita` | Get a nsfwURL of a okita (fate_all) image |
| `raikou` | Get a nsfwURL of a raikou (fate/grand order) image |
| `saint_martha`| Get a nsfwURL of a saint_martha (fate/grand order) image |
| `ushiwakamaru` |Get a nsfwURL of a ushiwakamaru (fate/grand order) image |
| `xuanzang` | Get a nsfwURL of a xuanzang (fate/grand order) image |
| `scathach` | Get a nsfwURL of a scathach (fate/grand order) image |
| `ahegao` | Gets a nsfwURL of a ahegao face |
| `jav` | Gets a nsfwURL of a jav image |
| `gif` | Gets a nsfwURL of a gif |
| `twitter` | Gets a nsfwURL of a twitter |
| `fgo` | Gets a nsfwURL of a Fate/Grand Order image/gif |
| `furry` | Gets a nsfwURL of a furry image/gif |
| `armpits`  | Get a nsfwURL of a armpits image/gif |
| `ass` | Get a nsfwURL of a ass image/gif |
| `bikini` | Get a nsfwURL of a bikini image/gif |
| `blowjob` | Get a nsfwURL of a blowjob image/gif |
| `blush` | Get a nsfwURL of a blush image/gif |
| `clothed_sex` | Get a nsfwURL of a clothed_sex image/gif |
| `cowgirl_position` | Get a nsfwURL of a cowgirl_position image/gif |
| `cum` | Get a nsfwURL of a cum |
| `dark_skin` | Get a nsfwURL of a dark_skin image |
| `doggystyle` | Get a nsfwURL of a doggystyle image/gif |
| `double_penetration` | Get a nsfwURL of a double_penetration |
| `foot_licking` | Get a nsfwURL of a foot_licking image/gif |
| `footjob` | Get a nsfwURL of a footjob image/gif |
| `furry` | Get a nsfwURL of a furry image/gif |
| `futanari` | Get a nsfwURL of a futanari image/gif |
| `gangbang` | Get a nsfwURL of a gangbang image/gif |
| `housewife` | Get a nsfwURL of a housewife |
| `impregnation` | Get a nsfwURL of a impregnation image |
| `large_breasts` | Get a nsfwURL of a large_breasts image/gif |
| `masturbation` | Get a nsfwURL of a masturbation |
| `milf` | Get a nsfwURL of a milf image/gif |
| `netorare` | Get a nsfwURL of a netorare image/gif |
| `pantyhose` | Get a nsfwURL of a pantyhose image/gif |
| `pervert` | Get a nsfwURL of a pervert |
| `pout` | Get a nsfwURL of a pout image |
| `pregnant` | Get a nsfwURL of a pregnant image/gif |
| `pubic_hair` | Get a nsfwURL of a pubic_hair |
| `pussy_juice` | Get a nsfwURL of a pussy_juice image/gif |
| `rape` | Get a nsfwURL of a rape image/gif |
| `school_uniform` | Get a nsfwURL of a school_uniform image/gif |
| `smell` | Get a nsfwURL of a smell image/gif |
| `sweat` | Get a nsfwURL of a sweat image/gif |
| `thick` | Get a nsfwURL of a thick |
| `twintails` | Get a nsfwURL of a twintails image |
| `ugly_man` | Get a nsfwURL of a ugly_man image/gif |
| `uncensored` | Get a nsfwURL of a uncensored |
| `yaoi` | Get a nsfwURL of a yaoi image/gif |
| `yuri` | Get a nsfwURL of a yuri |  

# Usage example
```py
import scathach
print(scathach.mashu())

>>> 'https://us.rule34.xxx/images/3804/d5197961261cd9cc5ceaeda082320a550546771d.jpg'
```

==> scathach-api-1.4.4.tar.gz: scathach-api-1.4.4/README.md <==
# scathach-api
[![pip](https://img.shields.io/pypi/v/scathach-api)](https://pypi.org/project/scathach-api/)
[![CodeFactor](https://www.codefactor.io/repository/github/sinkaroid/scathach-api.py/badge)](https://www.codefactor.io/repository/github/sinkaroid/scathach-api.py)
[![chat](https://img.shields.io/discord/734526032031514786?color=purple)](https://discord.gg/ykbD7zj)  
An advanced NSFW wrapper, complete rewrite and overhaul of the original Fate/Lewd Order API.  


# Install
```
pip install scathach-api
```

### Endpoints
call them as functions  

| Function | Description |
| -------- | ----------- |
| `abigail` | Get a nsfwURL of a abigail (fate/grand order) image |
| `anastasia` | Get a nsfwURL of a anastasia (fate/grand order) image |
| `artoria` | Get a nsfwURL of a artoria (fate_all) image |
| `bb` | Get a nsfwURL of a bb (fate_all) image|
| `consort_yu`  | Get a nsfwURL of a consort_yu (fate/grand order) image |
| `davinci` | Get a nsfwURL of a davinci (fate/grand order) image |
| `ereshkigal` | Get a nsfwURL of a ereshkigal (fate/grand order) image |
| `gudako` | Get a nsfwURL of a gudako (fate/grand order) image |
| `himiko` | Get a nsfwURL of a himiko (fate/grand order) image |
| `jeanne` | Get a nsfwURL of a jeanne (fate_all) image |
| `kama` | Get a nsfwURL of a kama (fate/grand order) image |
| `kiara` | Get a nsfwURL of a kiara (fate/grand order) image |
| `mashu` | Get a nsfwURL of a mashu (fate/grand order) image |
| `mordred` | Get a nsfwURL of a mordred (fate_all) image |
| `nero` | Get a nsfwURL of a nero (fate_all) image |
| `okita` | Get a nsfwURL of a okita (fate_all) image |
| `raikou` | Get a nsfwURL of a raikou (fate/grand order) image |
| `saint_martha`| Get a nsfwURL of a saint_martha (fate/grand order) image |
| `ushiwakamaru` |Get a nsfwURL of a ushiwakamaru (fate/grand order) image |
| `xuanzang` | Get a nsfwURL of a xuanzang (fate/grand order) image |
| `scathach` | Get a nsfwURL of a scathach (fate/grand order) image |
| `ahegao` | Gets a nsfwURL of a ahegao face |
| `jav` | Gets a nsfwURL of a jav image |
| `gif` | Gets a nsfwURL of a gif |
| `twitter` | Gets a nsfwURL of a twitter |
| `fgo` | Gets a nsfwURL of a Fate/Grand Order image/gif |
| `furry` | Gets a nsfwURL of a furry image/gif |
| `armpits`  | Get a nsfwURL of a armpits image/gif |
| `ass` | Get a nsfwURL of a ass image/gif |
| `bikini` | Get a nsfwURL of a bikini image/gif |
| `blowjob` | Get a nsfwURL of a blowjob image/gif |
| `blush` | Get a nsfwURL of a blush image/gif |
| `clothed_sex` | Get a nsfwURL of a clothed_sex image/gif |
| `cowgirl_position` | Get a nsfwURL of a cowgirl_position image/gif |
| `cum` | Get a nsfwURL of a cum |
| `dark_skin` | Get a nsfwURL of a dark_skin image |
| `doggystyle` | Get a nsfwURL of a doggystyle image/gif |
| `double_penetration` | Get a nsfwURL of a double_penetration |
| `foot_licking` | Get a nsfwURL of a foot_licking image/gif |
| `footjob` | Get a nsfwURL of a footjob image/gif |
| `furry` | Get a nsfwURL of a furry image/gif |
| `futanari` | Get a nsfwURL of a futanari image/gif |
| `gangbang` | Get a nsfwURL of a gangbang image/gif |
| `housewife` | Get a nsfwURL of a housewife |
| `impregnation` | Get a nsfwURL of a impregnation image |
| `large_breasts` | Get a nsfwURL of a large_breasts image/gif |
| `masturbation` | Get a nsfwURL of a masturbation |
| `milf` | Get a nsfwURL of a milf image/gif |
| `netorare` | Get a nsfwURL of a netorare image/gif |
| `pantyhose` | Get a nsfwURL of a pantyhose image/gif |
| `pervert` | Get a nsfwURL of a pervert |
| `pout` | Get a nsfwURL of a pout image |
| `pregnant` | Get a nsfwURL of a pregnant image/gif |
| `pubic_hair` | Get a nsfwURL of a pubic_hair |
| `pussy_juice` | Get a nsfwURL of a pussy_juice image/gif |
| `rape` | Get a nsfwURL of a rape image/gif |
| `school_uniform` | Get a nsfwURL of a school_uniform image/gif |
| `smell` | Get a nsfwURL of a smell image/gif |
| `sweat` | Get a nsfwURL of a sweat image/gif |
| `thick` | Get a nsfwURL of a thick |
| `twintails` | Get a nsfwURL of a twintails image |
| `ugly_man` | Get a nsfwURL of a ugly_man image/gif |
| `uncensored` | Get a nsfwURL of a uncensored |
| `yaoi` | Get a nsfwURL of a yaoi image/gif |
| `yuri` | Get a nsfwURL of a yuri |  

# Usage example
```py
import scathach
print(scathach.mashu())

>>> 'https://us.rule34.xxx/images/3804/d5197961261cd9cc5ceaeda082320a550546771d.jpg'
```
